| ibdsegments-package | R Documentation |
Identity by Descent (IBD) distributions in pedigrees. A Hidden Markov Model is used to compute identity coefficients, simulate IBD segments and to derive the distribution of total IBD sharing and segment count across chromosomes. The methods are applied in Kruijver (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3390/genes16050492")}. The probability that the total IBD sharing is zero can be computed using the method of Donnelly (1983) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/0040-5809(83)90004-7")}.
Maintainer: Maarten Kruijver maarten.kruijver@esr.cri.nz (ORCID)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.